@@ -1,8 +1,6 @@
-# Copyright (c) 2009-2015 Martin Becker.  All rights reserved.
-# This package is free software; you can redistribute it and/or modify it
-# under the same terms as Perl itself.
-#
-# $Id: GF2.pm 60 2015-05-18 08:47:12Z demetri $
+# Copyright (c) 2009-2019 Martin Becker, Blaubeuren.
+# This package is free software; you can distribute it and/or modify it
+# under the terms of the Artistic License 2.0 (see LICENSE file).
 
 package Math::ModInt::GF2;
 
@@ -23,7 +21,7 @@ use constant NFIELDS   => 1;
 BEGIN {
     require Math::ModInt;
     our @ISA     = qw(Math::ModInt);
-    our $VERSION = '0.011';
+    our $VERSION = '0.012';
 }
 
 my @base = map { bless [$_] } 0..1;     # singletons
@@ -84,6 +82,11 @@ sub residue {
     return $this->[F_RESIDUE];
 }
 
+sub signed_residue {
+    my ($this) = @_;
+    return - $this->[F_RESIDUE];
+}
+
 sub centered_residue {
     my ($this) = @_;
     return $this->[F_RESIDUE];
@@ -103,7 +106,7 @@ Math::ModInt::GF2 - integer arithmetic modulo 2
 
 =head1 VERSION
 
-This documentation refers to version 0.011 of Math::ModInt::GF2.
+This documentation refers to version 0.012 of Math::ModInt::GF2.
 
 =head1 SYNOPSIS
 
@@ -144,11 +147,10 @@ Martin Becker, E<lt>becker-cpan-mp@cozap.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009-2015 by Martin Becker.  All rights reserved.
+Copyright (c) 2009-2019 Martin Becker, Blaubeuren.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.6.0 or,
-at your option, any later version of Perl 5 you may have available.
+This library is free software; you can distribute it and/or modify it
+under the terms of the Artistic License 2.0 (see LICENSE file).
 
 =head1 DISCLAIMER OF WARRANTY
 
