@@ -1,8 +1,6 @@
-# Copyright (c) 2012-2015 Martin Becker.  All rights reserved.
-# This package is free software; you can redistribute it and/or modify it
-# under the same terms as Perl itself.
-#
-# $Id: GF3.pm 60 2015-05-18 08:47:12Z demetri $
+# Copyright (c) 2012-2019 Martin Becker, Blaubeuren.
+# This package is free software; you can distribute it and/or modify it
+# under the terms of the Artistic License 2.0 (see LICENSE file).
 
 package Math::ModInt::GF3;
 
@@ -23,7 +21,7 @@ use constant NFIELDS   => 1;
 BEGIN {
     require Math::ModInt;
     our @ISA     = qw(Math::ModInt);
-    our $VERSION = '0.011';
+    our $VERSION = '0.012';
 }
 
 my @base = map { bless [$_] } 0..2;     # singletons
@@ -38,6 +36,8 @@ my @pow  = (
     sub { $base[$_[0] % 2 + 1] },
 );
 
+*centered_residue = \&signed_residue;
+
 # ----- private methods -----
 
 sub _NEG { $neg[$_[0]->[F_RESIDUE]] }
@@ -68,7 +68,7 @@ Math::ModInt::GF3 - integer arithmetic modulo 3
 
 =head1 VERSION
 
-This documentation refers to version 0.011 of Math::ModInt::GF3.
+This documentation refers to version 0.012 of Math::ModInt::GF3.
 
 =head1 SYNOPSIS
 
@@ -109,11 +109,10 @@ Martin Becker, E<lt>becker-cpan-mp@cozap.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2012-2015 by Martin Becker.  All rights reserved.
+Copyright (c) 2012-2019 Martin Becker, Blaubeuren.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.6.0 or,
-at your option, any later version of Perl 5 you may have available.
+This library is free software; you can distribute it and/or modify it
+under the terms of the Artistic License 2.0 (see LICENSE file).
 
 =head1 DISCLAIMER OF WARRANTY
 
