@@ -1,8 +1,6 @@
-# Copyright (c) 2009-2015 Martin Becker.  All rights reserved.
-# This package is free software; you can redistribute it and/or modify it
-# under the same terms as Perl itself.
-#
-# $Id: Perl.pm 60 2015-05-18 08:47:12Z demetri $
+# Copyright (c) 2009-2019 Martin Becker, Blaubeuren.
+# This package is free software; you can distribute it and/or modify it
+# under the terms of the Artistic License 2.0 (see LICENSE file).
 
 package Math::ModInt::Perl;
 
@@ -28,7 +26,7 @@ use constant _OPT_LIMIT     => 32768;
 BEGIN {
     require Math::ModInt;
     our @ISA     = qw(Math::ModInt);
-    our $VERSION = '0.011';
+    our $VERSION = '0.012';
 }
 
 my %inverses = ();
@@ -144,7 +142,7 @@ sub _INV {
 
 sub _NEW {
     my ($this, $residue, $modulus) = @_;
-    my $class = ref($this);
+    my $class = ref $this;
     if ($class) {
         $modulus = $this->[F_MODULUS];
     }
@@ -200,7 +198,7 @@ Math::ModInt::Perl - modular integer arithmetic, powered by native Perl
 
 =head1 VERSION
 
-This documentation refers to version 0.011 of Math::ModInt::Perl.
+This documentation refers to version 0.012 of Math::ModInt::Perl.
 
 =head1 SYNOPSIS
 
@@ -250,11 +248,10 @@ Martin Becker, E<lt>becker-cpan-mp@cozap.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009-2015 by Martin Becker.  All rights reserved.
+Copyright (c) 2009-2019 Martin Becker, Blaubeuren.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.6.0 or,
-at your option, any later version of Perl 5 you may have available.
+This library is free software; you can distribute it and/or modify it
+under the terms of the Artistic License 2.0 (see LICENSE file).
 
 =head1 DISCLAIMER OF WARRANTY
 
